==> PHEindicatormethods_1.1.5.tar.gz: PHEindicatormethods/R/PHEindicatormethods.R <==
#' PHEindicatormethods: A package for performing standard statistics for public
#' health indicators
#'
#' @docType package
#' @name PHEindicatormethods
NULL

globalVariables(c("a_vals",
                  "adj_value",
                  "b_sqrt_a",
                  "b_vals",
                  "ei",
                  "esp2013",
                  "estimate",
                  "exp_x",
                  "expected",
                  "highergeog_column",
                  "invert_calc",
                  "l_2b_removed",
                  "Li_2b_removed",
                  "lowercl",
                  "method",
                  "model",
                  "naflag",
                  "nrefpop_calc",
                  "observed",
                  "p_2b_removed",
                  "p.value",
                  "qchisq",
                  "qi_2b_removed",
                  "qinverted",
                  "qnorm",
                  "qt",
                  "quantile",
                  "ref_rate",
                  "rii",
                  "rii_lowercl",
                  "rii_MAD",
                  "rii_uppercl",
                  "sd",
                  "SeSE_2b_removed",
                  "sii",
                  "sii_lowercl",
                  "sii_MAD",
                  "sii_uppercl",
                  "sq_rate",
                  "sqrt_a",
                  "startage_2b_removed",
                  "statistic",
                  "std.error",
                  "stdev",
                  "STi_2b_removed",
                  "stdpop_calc",
                  "term",
                  "total_count",
                  "total_pop",
                  "uppercl",
                  "value",
                  "Value",
                  "value_count",
                  "value_sum",
                  "value_transform",
                  "vardsr",
                  "W_spi_2b_removed",
                  "wt_rate",
                  "xrefpop_calc"
                  )
)

==> PHEindicatormethods_1.2.0.tar.gz: PHEindicatormethods/R/PHEindicatormethods.R <==
#' PHEindicatormethods: A package for performing standard statistics for public
#' health indicators
#'
#' @docType package
#' @name PHEindicatormethods
NULL

globalVariables(c("a_vals",
                  "adj_value",
                  "b_sqrt_a",
                  "b_vals",
                  "ei",
                  "esp2013",
                  "estimate",
                  "exp_x",
                  "expected",
                  "groupvars",
                  "invert_calc",
                  "l_2b_removed",
                  "Li_2b_removed",
                  "lowercl",
                  "lower95_0cl",
                  "lower99_8cl",
                  "method",
                  "model",
                  "naflag",
                  "nrefpop_calc",
                  "observed",
                  "p_2b_removed",
                  "p.value",
                  "qchisq",
                  "qi_2b_removed",
                  "qinverted",
                  "qnorm",
                  "qt",
                  "quantile",
                  "ref_rate",
                  "rii",
                  "rii_lowercl",
                  "rii_MAD",
                  "rii_uppercl",
                  "sd",
                  "SeSE_2b_removed",
                  "sii",
                  "sii_lowercl",
                  "sii_MAD",
                  "sii_uppercl",
                  "sq_rate",
                  "sqrt_a",
                  "standardised_pop",
                  "startage_2b_removed",
                  "statistic",
                  "std.error",
                  "stdev",
                  "STi_2b_removed",
                  "stdpop_calc",
                  "term",
                  "total_count",
                  "total_pop",
                  "uppercl",
                  "upper95_0cl",
                  "upper99_8cl",
                  "value",
                  "Value",
                  "value_count",
                  "value_sum",
                  "value_transform",
                  "vardsr",
                  "W_spi_2b_removed",
                  "wt_rate",
                  "xrefpop_calc"
                  )
)
